package MFVec3d;
use strict;
use warnings;

use rlib "./";

use MFValue;
use base qw(MFValue);

use SFVec3d;
our $SField = new SFVec3d;

1;
__END__
